==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_67.js <==
var searchData=
[
  ['g',['g',['../structplplot_1_1__N9.html#ac6f4b924e5b670191775937095230225',1,'plplot::_N9::g()'],['../structPLColor.html#ab71f4093766e02ce796389832582517a',1,'PLColor::g()']]],
  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structGcwPLdev.html#a4845487cd0dab9a9d812c29b315c3a87',1,'GcwPLdev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
  ['gcw_5ffunctions',['gcw_functions',['../gcwmodule_8c.html#adc37fe5d00f49d5e7b925d2435148df2',1,'gcwmodule.c']]],
  ['gcw_5foptions',['gcw_options',['../gcw_8c.html#a49f10f7277173818e15335b87b9bbab1',1,'gcw.c']]],
  ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
  ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
  ['get',['get',['../structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12',1,'tclMatrix::get()'],['../structplf2ops__t.html#a5e06163958c53e58712d8a76d6918b40',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
  ['get_5fattr',['get_attr',['../structswig__globalvar.html#a051e346d0cd7608bf99e96726022e88c',1,'swig_globalvar']]],
  ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
  ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
  ['getmethod',['getmethod',['../structswig__lua__attribute.html#ab18a92c81433b7b3de23856cda4b89b5',1,'swig_lua_attribute']]],
  ['gin',['gin',['../classwxPLDevBase.html#a9771d5071d232737f8deeb925628b924',1,'wxPLDevBase::gin()'],['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
  ['glyphlist',['glyphlist',['../struct__PlplotCanvasHacktextPriv.html#af8c534b7810b4b744a0e365e7a7b59f1',1,'_PlplotCanvasHacktextPriv']]],
  ['gradient_5findex',['gradient_index',['../structSVG.html#a1478ed065a8ac15a5ac5c7f3c03ce991',1,'SVG']]],
  ['graphics_5fanti_5faliasing',['graphics_anti_aliasing',['../structPLCairo.html#aaea63861125bfc78fd2d8e2f00d5fab4',1,'PLCairo::graphics_anti_aliasing()'],['../cairo_8c.html#a34b1934fb70098cfce56e45d2a44ea0e',1,'graphics_anti_aliasing():&#160;cairo.c']]],
  ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
  ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct']]],
  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae64ff93e7451043c87595b1f57578dc6',1,'plplot.core.plplotjavacConstants.GRID_CSA()'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()']]],
  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a34b6315c9ae7a36da1290ccadd7202f3',1,'plplot.core.plplotjavacConstants.GRID_DTLI()'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()']]],
  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa1b79f0206722f1c4a13c357ab3d2e35',1,'plplot.core.plplotjavacConstants.GRID_NNAIDW()'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()']]],
  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a971b5a9980787f3b5aa39318ed8f4349',1,'plplot.core.plplotjavacConstants.GRID_NNI()'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()']]],
  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab98f0ef378fda8360117e1f55df273ec',1,'plplot.core.plplotjavacConstants.GRID_NNIDW()'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()']]],
  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3eae2031bbcb11d266efd99b44adcce1',1,'plplot.core.plplotjavacConstants.GRID_NNLI()'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()']]],
  ['group_5fhidden',['group_hidden',['../structGcwPLdev.html#aa1f8274a8e0dbcc26639afb4df64291c',1,'GcwPLdev']]],
  ['group_5fpersistent',['group_persistent',['../structGcwPLdev.html#a15333e47086100fa09de829eae5e56f1',1,'GcwPLdev']]],
  ['group_5fvisible',['group_visible',['../structGcwPLdev.html#a306dbd9ad448821312f3b25e6c85aa02',1,'GcwPLdev']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_67.js <==
var searchData=
[
  ['g',['g',['../structplplot_1_1__N9.html#ac6f4b924e5b670191775937095230225',1,'plplot::_N9::g()'],['../structPLColor.html#ab71f4093766e02ce796389832582517a',1,'PLColor::g()']]],
  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
  ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
  ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
  ['get',['get',['../structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12',1,'tclMatrix::get()'],['../structplf2ops__t.html#a5e06163958c53e58712d8a76d6918b40',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
  ['get_5fattr',['get_attr',['../structswig__globalvar.html#a051e346d0cd7608bf99e96726022e88c',1,'swig_globalvar']]],
  ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
  ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
  ['getmethod',['getmethod',['../structswig__lua__attribute.html#ab18a92c81433b7b3de23856cda4b89b5',1,'swig_lua_attribute']]],
  ['gin',['gin',['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
  ['gradient_5findex',['gradient_index',['../structSVG.html#a1478ed065a8ac15a5ac5c7f3c03ce991',1,'SVG']]],
  ['graphics_5fanti_5faliasing',['graphics_anti_aliasing',['../structPLCairo.html#aaea63861125bfc78fd2d8e2f00d5fab4',1,'PLCairo::graphics_anti_aliasing()'],['../cairo_8c.html#a34b1934fb70098cfce56e45d2a44ea0e',1,'graphics_anti_aliasing():&#160;cairo.c']]],
  ['graphicsin',['graphicsIn',['../structMemoryMapHeader.html#ae4905de4351f1c48da7b902a5cca0920',1,'MemoryMapHeader']]],
  ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
  ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct']]],
  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae64ff93e7451043c87595b1f57578dc6',1,'plplot.core.plplotjavacConstants.GRID_CSA()'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()']]],
  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a34b6315c9ae7a36da1290ccadd7202f3',1,'plplot.core.plplotjavacConstants.GRID_DTLI()'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()']]],
  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa1b79f0206722f1c4a13c357ab3d2e35',1,'plplot.core.plplotjavacConstants.GRID_NNAIDW()'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()']]],
  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a971b5a9980787f3b5aa39318ed8f4349',1,'plplot.core.plplotjavacConstants.GRID_NNI()'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()']]],
  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab98f0ef378fda8360117e1f55df273ec',1,'plplot.core.plplotjavacConstants.GRID_NNIDW()'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()']]],
  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3eae2031bbcb11d266efd99b44adcce1',1,'plplot.core.plplotjavacConstants.GRID_NNLI()'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()']]]
];
